@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ('all' => [ qw(new get_info make_report)]);
 our @EXPORT_OK = (@{$EXPORT_TAGS{'all'}});
 our @EXPORT = qw();
-our $VERSION ='1.4';
+our $VERSION ='1.5';
 #####################################################
 my ($class, $this, $router);
 #####################################################
@@ -72,3 +72,55 @@ sub make_report(){
     close CSV;
 }
 1;
+__END__
+ 
+ 
+Hide 48 lines of Pod
+=head1 NAME
+ 
+ios get interfaces - Get interfaces from cisco ios conf.
+ 
+=head1 SYNOPSIS
+ 
+use strict;
+ 
+use warnings;
+ 
+use ios_get_interfaces;
+ 
+my%info = (name => "router_a", showrun_file => "show_running_config.txt", csv=>"router_a.csv");
+ 
+my$router = ios_get_interfaces->new(\%info);
+ 
+my$interfaces = $router->get_info();
+ 
+print @{$interfaces};
+ 
+$router->make_report();
+ 
+=head1 DESCRIPTION
+ 
+ 
+Get interfaces from cisco ios conf
+ 
+ 
+=head2 EXPORT
+ 
+None by default.
+ 
+=head1 SEE ALSO
+ 
+=head1 AUTHOR
+ 
+Cladi, E<lt>cladi@cpan.orgE<gt>
+ 
+=head1 COPYRIGHT AND LICENSE
+ 
+Copyright (C) 2017 by Cladi Di Domenico
+ 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.1 or,
+at your option, any later version of Perl 5 you may have available.
+ 
+ 
+=cut
